@@ -1,22 +1,26 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '3.000';
+$VERSION = '3.018_001';
 
 use base 'Mail::Reporter';
 
+use strict;
+use warnings;
+
 use Mail::Message::Field;
 use Mail::Message::Body::Lines;
 use Mail::Message::Body::File;
 
 use Carp;
-use Scalar::Util     qw/weaken refaddr/;
+use Scalar::Util     qw/weaken refaddr blessed/;
 use File::Basename   qw/basename/;
 
 use MIME::Types;
@@ -39,21 +43,19 @@ my $body_count = 0;  # to be able to compare bodies for equivalence.
 sub new(@)
 {   my $class = shift;
 
-    return $class->SUPER::new(@_)
-         unless $class eq __PACKAGE__;
+    $class eq __PACKAGE__
+        or return $class->SUPER::new(@_);
 
     my %args  = @_;
 
-      exists $args{file}
-    ? Mail::Message::Body::File->new(@_)
-    : Mail::Message::Body::Lines->new(@_);
+    exists $args{file}
+      ? Mail::Message::Body::File->new(@_)
+      : Mail::Message::Body::Lines->new(@_);
 }
 
 # All body implementations shall implement all of the following!!
-
 sub _data_from_filename(@)   {shift->notImplemented}
 sub _data_from_filehandle(@) {shift->notImplemented}
-sub _data_from_glob(@)       {shift->notImplemented}
 sub _data_from_lines(@)      {shift->notImplemented}
 
 sub init($)
@@ -63,19 +65,23 @@ sub init($)
 
     $self->{MMB_modified} = $args->{modified} || 0;
 
-    my $filename;
+    my $filename = $args->{filename};
+	my $mime     = $args->{mime_type};
+
     if(defined(my $file = $args->{file}))
     {
         if(!ref $file)
         {   $self->_data_from_filename($file) or return;
-            $filename = $file;
+            $filename ||= $file;
+            $mime ||= $mime_types->mimeTypeOf($filename)
+                  || (-T $file ? 'text/plain' : 'application/octet-stream');
+        }
+        elsif(ref $file eq 'GLOB' || (blessed $file && $file->isa('IO::Handle')))
+        {   $self->_data_from_filehandle($file) or return;
         }
-        elsif(ref $file eq 'GLOB')
-        {   $self->_data_from_glob($file) or return }
-        elsif($file->isa('IO::Handle'))
-        {   $self->_data_from_filehandle($file) or return }
         else
-        {   croak "message body: illegal datatype `".ref($file)."' for file option" }
+        {   croak "message body: illegal datatype `".ref($file)."' for file option";
+        }
     }
     elsif(defined(my $data = $args->{data}))
     {
@@ -87,7 +93,8 @@ sub init($)
         {   $self->_data_from_lines($data) or return;
         }
         else
-        {   croak "message body: illegal datatype `".ref($data)."' for data option" }
+        {   croak "message body: illegal datatype `".ref($data)."' for data option";
+        }
     }
     elsif(! $self->isMultipart && ! $self->isNested)
     {   # Neither 'file' nor 'data', so empty body.
@@ -96,21 +103,15 @@ sub init($)
 
     # Set the content info
 
-    my ($mime, $transfer, $disp, $charset, $descr, $cid) = @$args{
-       qw/mime_type transfer_encoding disposition charset
-          description content_id/ }; 
+    my ($transfer, $disp, $descr, $cid, $lang) = @$args{
+       qw/transfer_encoding disposition description content_id language/ };
 
     if(defined $filename)
-    {   $disp = Mail::Message::Field->new
-           ('Content-Disposition' => (-T $filename ? 'inline':'attachment')
-           , filename => basename($filename)
-           ) unless defined $disp;
-
-        unless(defined $mime)
-        {   $mime = $mime_types->mimeTypeOf($filename);
-            $mime = -T $filename ? 'text/plain' : 'application/octet-stream'
-                unless defined $mime;
-        }
+    {   $disp //= Mail::Message::Field->new
+          ( 'Content-Disposition' => (-T $filename ? 'inline' : 'attachment')
+          , filename => basename($filename)
+          );
+        $mime //= $mime_types->mimeTypeOf($filename);
     }
 
     if(ref $mime && $mime->isa('MIME::Type'))
@@ -118,14 +119,14 @@ sub init($)
     }
 
     if(defined(my $based = $args->{based_on}))
-    {   $mime     = $based->type             unless defined $mime;
-        $transfer = $based->transferEncoding unless defined $transfer;
-        $disp     = $based->disposition      unless defined $disp;
-        $descr    = $based->description      unless defined $descr;
-        $cid      = $based->contentId        unless defined $cid;
+    {   $mime     //= $based->type;
+        $transfer //= $based->transferEncoding;
+        $disp     //= $based->disposition;
+        $descr    //= $based->description;
+        $lang     //= $based->language;
+        $cid      //= $based->contentId;
 
-        $self->{MMB_checked}
-               = defined $args->{checked} ? $args->{checked} : $based->checked;
+        $self->{MMB_checked} = exists $args->{checked} ? $args->{checked} : $based->checked;
     }
     else
     {   $transfer = $args->{transfer_encoding};
@@ -134,17 +135,20 @@ sub init($)
 
     $mime ||= 'text/plain';
     $mime = $self->type($mime);
-    $mime->attribute(charset => ($charset || 'PERL'))
-        if $mime =~ m!^text/!i && !$mime->attribute('charset');
+
+    my $default_charset = exists $args->{charset} ? $args->{charset} : 'PERL';
+    $mime->attribute(charset => $default_charset)
+        if $default_charset
+        && $mime =~ m!^text/!i
+        && !$mime->attribute('charset');
 
     $self->transferEncoding($transfer) if defined $transfer;
     $self->disposition($disp)          if defined $disp;
     $self->description($descr)         if defined $descr;
+    $self->language($lang)             if defined $lang;
     $self->contentId($cid)             if defined $cid;
     $self->type($mime);
 
-    $self->{MMB_eol}   = $args->{eol} || 'NATIVE';
-
     # Set message where the body belongs to.
 
     $self->message($args->{message})
@@ -155,6 +159,7 @@ sub init($)
 }
 
 
+
 sub clone() {shift->notImplemented}
 
 #------------------------------------------
@@ -165,37 +170,6 @@ sub decoded(@)
     $self->encode(charset => 'PERL', transfer_encoding => 'none', @_);
 }
 
-
-sub eol(;$)
-{   my $self = shift;
-    return $self->{MMB_eol} unless @_;
-
-    my $eol  = shift;
-    if($eol eq 'NATIVE')
-    {   $eol = $^O =~ m/^win/i ? 'CRLF'
-             : $^O =~ m/^mac/i ? 'CR'
-             :                   'LF';
-    }
-
-    return $self if $eol eq $self->{MMB_eol} && $self->checked;
-    my $lines = $self->lines;
-    if(@$lines)
-    {   # sometimes texts lack \n on last line
-        $lines->[-1] .= "\n";
-       
-
-           if($eol eq 'CR')   {s/[\015\012]+$/\015/     for @$lines}
-        elsif($eol eq 'LF')   {s/[\015\012]+$/\012/     for @$lines}
-        elsif($eol eq 'CRLF') {s/[\015\012]+$/\015\012/ for @$lines}
-        else
-        {   $self->log(WARNING => "Unknown line terminator $eol ignored");
-            return $self->eol('NATIVE');
-        }
-    }
-
-    (ref $self)->new(based_on => $self, eol => $eol, data => $lines);
-}
-
 #------------------------------------------
 
 
@@ -226,16 +200,14 @@ sub partNumberOf($)
 
 #------------------------------------------
 
-
 sub type(;$)
 {   my $self = shift;
     return $self->{MMB_type} if !@_ && defined $self->{MMB_type};
 
     delete $self->{MMB_mime};
-    my $type = defined $_[0] ? shift : 'text/plain';
+    my $type = shift // 'text/plain';
 
-    $self->{MMB_type} = ref $type ? $type->clone
-      : Mail::Message::Field->new('Content-Type' => $type);
+    $self->{MMB_type} = ref $type ? $type->clone : Mail::Message::Field->new('Content-Type' => $type);
 }
 
 
@@ -245,12 +217,7 @@ sub mimeType()
 
     my $field = $self->{MMB_type};
     my $body  = defined $field ? $field->body : '';
-
-    return $self->{MMB_mime} = $mime_plain
-       unless length $body;
-
-    $self->{MMB_mime}
-       = $mime_types->type($body) || MIME::Type->new(type => $body);
+    $self->{MMB_mime} = length $body ? ($mime_types->type($body) || MIME::Type->new(type => $body)) : $mime_plain;
 }
 
 
@@ -273,7 +240,7 @@ sub description(;$)
 
     my $disp = defined $_[0] ? shift : 'none';
     $self->{MMB_description} = ref $disp ? $disp->clone
-       : Mail::Message::Field->new('Content-Description' => $disp);
+      : Mail::Message::Field->new('Content-Description' => $disp);
 }
 
 
@@ -283,8 +250,23 @@ sub disposition(;$)
 
     my $disp = defined $_[0] ? shift : 'none';
 
-    $self->{MMB_disposition} = ref $disp ? $disp->clone
-       : Mail::Message::Field->new('Content-Disposition' => $disp);
+    $self->{MMB_disposition} = blessed $disp ? $disp->clone
+      : Mail::Message::Field->new('Content-Disposition' => $disp);
+}
+
+
+sub language(@)
+{	my $self = shift;
+	return $self->{MMB_lang} if !@_ && $self->{MMB_lang};
+
+	my $langs
+	  = @_ > 1        ? (join ', ', @_)
+	  : blessed $_[0] ? $_[0]
+	  : ref $_[0] eq 'ARRAY' ? (join ', ', @{$_[0]}) : $_[0];
+
+	$self->{MMB_lang} = ! defined $langs || ! length $langs ? undef
+	  : blessed $langs ? $langs->clone
+	  : Mail::Message::Field->new('Content-Language' => $langs);
 }
 
 
@@ -294,7 +276,7 @@ sub contentId(;$)
 
     my $cid = defined $_[0] ? shift : 'none';
     $self->{MMB_id} = ref $cid ? $cid->clone
-       : Mail::Message::Field->new('Content-ID' => $cid);
+      : Mail::Message::Field->new('Content-ID' => $cid);
 }
 
 
@@ -318,7 +300,7 @@ sub string_unless_carp()
 {   my $self  = shift;
     return $self->string unless (caller)[0] eq 'Carp';
 
-    (my $class = ref $self) =~ s/^Mail::Message/MM/;
+    my $class = ref $self =~ s/^Mail::Message/MM/r;
     "$class object";
 }
 
@@ -340,9 +322,9 @@ sub write(@)
     my $filename = $args{filename};
     die "No filename for write() body" unless defined $filename;
 
-    open OUT, '>', $filename or return;
-    $self->print(\*OUT);
-    close OUT or return undef;
+    open my $out, '>', $filename or return;
+    $self->print($out);
+    $out->close or return undef;
     $self;
 }
 
@@ -370,6 +352,7 @@ sub contentInfoTo($)
     $head->set($self->transferEncoding);
     $head->set($self->disposition);
     $head->set($self->description);
+    $head->set($self->language);
     $head->set($self->contentId);
     $self;
 }
@@ -380,15 +363,16 @@ sub contentInfoFrom($)
 
     $self->type($head->get('Content-Type', 0));
 
-    my ($te, $disp, $desc, $cid)
+    my ($te, $disp, $desc, $cid, $lang)
       = map { my $x = $head->get("Content-$_") || '';
               s/^\s+//,s/\s+$// for $x;
               length $x ? $x : undef
-            } qw/Transfer-Encoding Disposition Description ID/;
+            } qw/Transfer-Encoding Disposition Description ID Language/;
 
     $self->transferEncoding($te);
     $self->disposition($disp);
     $self->description($desc);
+    $self->language($lang);
     $self->contentId($cid);
 
     delete $self->{MMB_mime};
@@ -399,7 +383,7 @@ sub contentInfoFrom($)
 
 sub modified(;$)
 {  my $self = shift;
-   return $self->isModified unless @_;  # compat 2.036
+   @_ or return $self->isModified;  # compat 2.036
    $self->{MMB_modified} = shift;
 }
 
@@ -409,7 +393,7 @@ sub isModified() { shift->{MMB_modified} }
 
 sub fileLocation(;@)
 {   my $self = shift;
-    return @$self{ qw/MMB_begin MMB_end/ } unless @_;
+    @_ or return @$self{ qw/MMB_begin MMB_end/ };
     @$self{ qw/MMB_begin MMB_end/ } = @_;
 }
 
@@ -427,25 +411,24 @@ sub load() {shift}
 #------------------------------------------
 
 
-my @in_encode = qw/check encode encoded eol isBinary isText unify
-                   dispositionFilename/;
-my %in_module = map { ($_ => 'encode') } @in_encode;
+my @in_encode = qw/check encode encoded eol isBinary isText unify dispositionFilename/;
+my %in_module = map +($_ => 'encode'), @in_encode;
 
 sub AUTOLOAD(@)
 {   my $self  = shift;
     our $AUTOLOAD;
-    (my $call = $AUTOLOAD) =~ s/.*\:\://g;
+    my $call = $AUTOLOAD =~ s/.*\:\://gr;
 
     my $mod = $in_module{$call} || 'construct';
-    if($mod eq 'encode'){ require Mail::Message::Body::Encode    }
-    else                { require Mail::Message::Body::Construct }
+    if($mod eq 'encode') { require Mail::Message::Body::Encode    }
+    else                 { require Mail::Message::Body::Construct }
 
     no strict 'refs';
     return $self->$call(@_) if $self->can($call);  # now loaded
 
-    # Try parental AUTOLOAD
-    Mail::Reporter->$call(@_);
-}   
+	# AUTOLOAD inheritance is a pain
+	confess "Method $call() is not defined for a ", ref $self;
+}
 
 #------------------------------------------
 
