@@ -1,15 +1,19 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-
-use strict;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.000';
+$VERSION = '3.018_001';
 
 
+use strict;
+use warnings;
+
 use Mail::Message::Head::Complete  ();
 use Mail::Message::Body::Lines     ();
 use Mail::Message::Body::Multipart ();
@@ -18,8 +22,6 @@ use Mail::Message::Field           ();
 
 use Mail::Address  ();
 
-use Scalar::Util   qw(reftype);
-
 
 sub build(@)
 {   my $class = shift;
@@ -37,7 +39,7 @@ sub build(@)
       :               ();
 
     my ($head, @headerlines);
-    my ($type, $transfenc, $dispose, $descr, $cid);
+    my ($type, $transfenc, $dispose, $descr, $cid, $lang);
     while(@_)
     {   my $key = shift;
         if(ref $key && $key->isa('Mail::Message::Field'))
@@ -46,6 +48,7 @@ sub build(@)
             elsif($name eq 'content-transfer-encoding') { $transfenc = $key }
             elsif($name eq 'content-disposition') { $dispose = $key }
             elsif($name eq 'content-description') { $descr   = $key }
+            elsif($name eq 'content-language')    { $lang    = $key }
             elsif($name eq 'content-id')          { $cid     = $key }
             else { push @headerlines, $key }
             next;
@@ -62,33 +65,33 @@ sub build(@)
         {   @data = Mail::Message::Body->new(data => $value) }
         elsif($key eq 'file' || $key eq 'files')
         {   @data = map Mail::Message::Body->new(file => $_)
-              , reftype $value eq 'ARRAY' ? @$value : $value;
+              , ref $value eq 'ARRAY' ? @$value : $value;
         }
         elsif($key eq 'attach')
-        {   foreach my $c (reftype $value eq 'ARRAY' ? @$value : $value)
-	    {   defined $c or next;
+        {   foreach my $c (ref $value eq 'ARRAY' ? @$value : $value)
+            {   defined $c or next;
                 push @data, ref $c && $c->isa('Mail::Message')
 		          ? Mail::Message::Body::Nested->new(nested => $c)
-			  : $c;
+                  : $c;
             }
-	}
-        elsif($key =~
-           m/^content\-(type|transfer\-encoding|disposition|description|id)$/i )
+        }
+        elsif($key =~ m/^content\-(type|transfer\-encoding|disposition|language|description|id)$/i )
         {   my $k     = lc $1;
             my $field = Mail::Message::Field->new($key, $value);
                if($k eq 'type')        { $type    = $field }
             elsif($k eq 'disposition') { $dispose = $field }
             elsif($k eq 'description') { $descr   = $field }
+            elsif($k eq 'language')    { $lang    = $field }
             elsif($k eq 'id')          { $cid     = $field }
             else                     { $transfenc = $field }
         }
         elsif($key =~ m/^[A-Z]/)
         {   push @headerlines, $key, $value }
         else
-        {   $class->log(WARNING => "Skipped unknown key $key in build");
+        {   $class->log(WARNING => "Skipped unknown key '$key' in build");
         }
 
-        push @parts, grep {defined $_} @data if @data;
+        push @parts, grep defined, @data;
     }
 
     my $body
@@ -100,6 +103,7 @@ sub build(@)
     $body->type($type)           if defined $type;
     $body->disposition($dispose) if defined $dispose;
     $body->description($descr)   if defined $descr;
+    $body->language($lang)       if defined $lang;
     $body->contentId($cid)       if defined $cid;
     $body->transferEncoding($transfenc) if defined $transfenc;
 
