@@ -1,16 +1,22 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Fast;
 use vars '$VERSION';
-$VERSION = '3.000';
+$VERSION = '3.018_001';
 
 use base 'Mail::Message::Field';
 
+use strict;
+use warnings;
+
+use Scalar::Util  qw/blessed/;
+
 
 #------------------------------------------
 #
@@ -78,8 +84,7 @@ sub foldedBody($)
 sub print(;$)
 {   my $self = shift;
     my $fh   = shift || select;
-    if(ref $fh eq 'GLOB') { print $fh $self->[0].':'.$self->[1]   }
-    else                  { $fh->print($self->[0].':'.$self->[1]) }
+    $fh->print($self->[0].':'.$self->[1]);
     $self;
 }
 
