@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-
-use strict;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Head::Partial;
 use vars '$VERSION';
-$VERSION = '3.000';
+$VERSION = '3.018_001';
 
 use base 'Mail::Message::Head::Complete';
 
+use strict;
+use warnings;
+
 use Scalar::Util 'weaken';
 
 
@@ -46,8 +50,6 @@ sub removeFieldsExcept(@)
     $self->cleanupOrderedFields;
 }
 
-#------------------------------------------
-
 
 sub removeResentGroups()
 {   my $self = shift;
@@ -67,8 +69,6 @@ sub removeResentGroups()
     $found;
 }
 
-#------------------------------------------
-
 
 sub removeListGroup()
 {   my $self = shift;
@@ -87,8 +87,6 @@ sub removeListGroup()
     $found;
 }
 
-#------------------------------------------
-
 
 sub removeSpamGroups()
 {   my $self = shift;
@@ -107,8 +105,6 @@ sub removeSpamGroups()
     $found;
 }
 
-#------------------------------------------
-
 
 sub cleanupOrderedFields()
 {   my $self = shift;
@@ -121,6 +117,4 @@ sub cleanupOrderedFields()
 #------------------------------------------
 
 
-#------------------------------------------
-
 1;
