@@ -1,17 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-
-use strict;
-use warnings;
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Replace::MailHeader;
 use vars '$VERSION';
-$VERSION = '3.000';
+$VERSION = '3.018_001';
 
 use base 'Mail::Message::Head::Complete';
 
+use strict;
+use warnings;
+
 
 sub new(@)
 {   my $class = shift;
@@ -51,7 +54,7 @@ sub add($$)
 
 sub replace($$;$)
 {   my ($self, $tag, $line, $index) = @_;
-    $line =~ s/^([^:]+)\:\s*// && ($tag = $1) unless defined $tag;
+    $tag //= $line =~ s/^([^:]+)\:\s*// ? $1 : 'MISSING';
 
     my $field  = Mail::Message::Field::Fast->new($tag, $line);
     my @fields = $self->get($tag);
@@ -61,15 +64,18 @@ sub replace($$;$)
     $field;
 }
 
+#------------------
 
 sub get($;$)
 {   my $head = shift->head;
-    my @ret  = map { $head->get(@_) } @_;
+    my @ret  = map $head->get(@_), @_;
 
-    if(wantarray) { return @ret ? map({$_->unfoldedBody} @ret) : () }
-    else          { return @ret ? $ret[0]->unfoldedBody : undef }
+       wantarray ? (map $_->unfoldedBody, @ret)
+     : @ret      ? $ret[0]->unfoldedBody
+     : undef;
 }
 
+#------------------
 
 sub modify(;$)
 {   my $self = shift;
@@ -92,7 +98,7 @@ sub mail_from(;$)
 sub fold(;$)
 {   my $self = shift;
     my $wrap = @_ ? shift : $self->fold_length;
-    $_->setWrapLength($wrap) foreach $self->orderedFields;
+    $_->setWrapLength($wrap) for $self->orderedFields;
     $self;
 }
 
@@ -100,7 +106,7 @@ sub fold(;$)
 sub unfold(;$)
 {   my $self = shift;
     my @fields = @_ ? $self->get(shift) : $self->orderedFields;
-    $_->setWrapLength(100_000) foreach @fields;  # blunt approach
+    $_->setWrapLength(100_000) for @fields;  # blunt approach
     $self;
 }
 
@@ -126,11 +132,7 @@ sub extract($)
 
 sub read($)
 {   my ($self, $file) = @_;
-    my $parser = Mail::Box::Parser::Perl->new
-       ( filename  => ('from file-handle '.ref $file)
-       , file      => $file
-       , trusted   => 1
-       );
+    my $parser = Mail::Box::Parser::Perl->new(filename => ('from file-handle '.ref $file), file => $file, trusted => 1);
     $self->read($parser);
     $parser->close;
     $self;
